@@ -136,7 +136,8 @@ class AsteroidGame(arcade.Window):
         self.score = score if score else Score()
 
         if self.scenario._ammo_limit_multiplier:
-            self.score.bullets_remaining = [self.scenario.bullet_limit for _ in self.scenario.ship_states]
+            # self.score.bullets_remaining = [self.scenario.bullet_limit for _ in self.scenario.ship_states]
+            self.score.bullets_remaining = [self.scenario.bullet_limit for _ in range(2)]
 
         self.stop_if_no_ammo = self.scenario.stop_if_no_ammo
 
@@ -386,7 +387,7 @@ class AsteroidGame(arcade.Window):
             self.game_over = StoppingCondition.no_lives
         elif self.score.time >= self.scenario.time_limit:
             self.game_over = StoppingCondition.no_time
-        elif self.stop_if_no_ammo and all([sprite.bullets_remaining == 0 for sprite in self.player_sprite_list]):
+        elif self.stop_if_no_ammo and all([sprite.bullets_remaining == 0 for sprite in self.player_sprite_list]) and not self.bullet_list:
             self.game_over = StoppingCondition.no_bullets
         else:
             # If there are no stopping conditions, update the time/frame count
@@ -405,6 +406,7 @@ class AsteroidGame(arcade.Window):
             # Break up and remove asteroids if there are bullet-asteroid collisions
             for asteroid in asteroids:
                 self.split_asteroid(cast(AsteroidSprite, asteroid), bullet.team)  # expected AsteroidSprite, got Sprite instead
+                self.score.asteroids_hit_by_bullets[bullet.team-1] += 1
                 bullet.remove_from_sprite_lists()
 
     def check_asteroid_ship_collisions(self):
